agenttools.PersistenceAgent
===========================

.. abjad-lineage:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent

.. autoclass:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.as_ly
      ~abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.as_midi
      ~abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.as_module
      ~abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.as_pdf
      ~abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.as_png
      ~abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.client
      ~abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.__eq__
      ~abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.__format__
      ~abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.__hash__
      ~abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.__ne__
      ~abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.client
   :noindex:

Methods
-------

.. automethod:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.as_ly
   :noindex:

.. automethod:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.as_midi
   :noindex:

.. automethod:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.as_module
   :noindex:

.. automethod:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.as_pdf
   :noindex:

.. automethod:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.as_png
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.__eq__
   :noindex:

.. automethod:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.__format__
   :noindex:

.. automethod:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.__hash__
   :noindex:

.. automethod:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.__ne__
   :noindex:

.. automethod:: abjad.tools.agenttools.PersistenceAgent.PersistenceAgent.__repr__
   :noindex:
